# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/common.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x18\x63ogment/api/common.proto\x12\x07\x63ogment\x1a\x1fgoogle/protobuf/timestamp.proto\"\x10\n\x0eVersionRequest\"g\n\x0bVersionInfo\x12.\n\x08versions\x18\x01 \x03(\x0b\x32\x1c.cogment.VersionInfo.Version\x1a(\n\x07Version\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"4\n\x0fObservationData\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"u\n\x0bObservation\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x18.cogment.ObservationData\"\x19\n\x06\x41\x63tion\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"a\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12\x10\n\x08\x61\x63tor_id\x18\x01 \x01(\r\x12\x0f\n\x07tick_id\x18\x02 \x01(\r\x12\r\n\x05value\x18\x03 \x01(\x02\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='cogment.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=86,
)


_VERSIONINFO_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='cogment.VersionInfo.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogment.VersionInfo.Version.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='cogment.VersionInfo.Version.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=191,
)

_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='cogment.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='cogment.VersionInfo.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VERSIONINFO_VERSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=191,
)


_OBSERVATIONDATA = _descriptor.Descriptor(
  name='ObservationData',
  full_name='cogment.ObservationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.ObservationData.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='cogment.ObservationData.snapshot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=245,
)


_OBSERVATION = _descriptor.Descriptor(
  name='Observation',
  full_name='cogment.Observation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.Observation.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogment.Observation.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='cogment.Observation.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=364,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='cogment.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.Action.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=391,
)


_FEEDBACK = _descriptor.Descriptor(
  name='Feedback',
  full_name='cogment.Feedback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='cogment.Feedback.actor_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.Feedback.tick_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.Feedback.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogment.Feedback.confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.Feedback.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=490,
)

_VERSIONINFO_VERSION.containing_type = _VERSIONINFO
_VERSIONINFO.fields_by_name['versions'].message_type = _VERSIONINFO_VERSION
_OBSERVATION.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OBSERVATION.fields_by_name['data'].message_type = _OBSERVATIONDATA
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['ObservationData'] = _OBSERVATIONDATA
DESCRIPTOR.message_types_by_name['Observation'] = _OBSERVATION
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['Feedback'] = _FEEDBACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQUEST,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.VersionRequest)
  ))
_sym_db.RegisterMessage(VersionRequest)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), dict(

  Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), dict(
    DESCRIPTOR = _VERSIONINFO_VERSION,
    __module__ = 'cogment.api.common_pb2'
    # @@protoc_insertion_point(class_scope:cogment.VersionInfo.Version)
    ))
  ,
  DESCRIPTOR = _VERSIONINFO,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.VersionInfo)
  ))
_sym_db.RegisterMessage(VersionInfo)
_sym_db.RegisterMessage(VersionInfo.Version)

ObservationData = _reflection.GeneratedProtocolMessageType('ObservationData', (_message.Message,), dict(
  DESCRIPTOR = _OBSERVATIONDATA,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ObservationData)
  ))
_sym_db.RegisterMessage(ObservationData)

Observation = _reflection.GeneratedProtocolMessageType('Observation', (_message.Message,), dict(
  DESCRIPTOR = _OBSERVATION,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Observation)
  ))
_sym_db.RegisterMessage(Observation)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
  DESCRIPTOR = _ACTION,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Action)
  ))
_sym_db.RegisterMessage(Action)

Feedback = _reflection.GeneratedProtocolMessageType('Feedback', (_message.Message,), dict(
  DESCRIPTOR = _FEEDBACK,
  __module__ = 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Feedback)
  ))
_sym_db.RegisterMessage(Feedback)


# @@protoc_insertion_point(module_scope)



class ActorClass:
    def __init__(self, name, action_space, observation_space,
                 observation_delta, observation_delta_apply_fn, feedback_space):
        self.name = name
        self.action_space = action_space
        self.observation_space = observation_space
        self.observation_delta = observation_delta
        self.observation_delta_apply_fn = observation_delta_apply_fn
        self.feedback_space = feedback_space
